@@ -51,7 +51,7 @@ class QDomDocument;
 // we pass references of in, when used by external modules
 // e.g.
 //     when building chartshapecore.lib, the forward-declaration
-//     appraoch lead to unresolved externals warnings when it used
+//     approach lead to unresolved externals warnings when it used
 //     the pagelayout functions.
 //     Also when building calligra_shape_formular.dll - FormulaDocument
 //     referenced the same two pagelayout functions incorrectly.
@@ -61,6 +61,10 @@ class QDomDocument;
     struct KoPageLayout;
 #endif
 
+namespace KPlato {
+    class Project;
+}
+
 class KoVersionInfo
 {
 public:
@@ -82,8 +86,8 @@ public:
 class KOMAIN_EXPORT KoDocument : public QObject, public KoDocumentBase
 {
     Q_OBJECT
-    Q_PROPERTY(bool backupFile READ backupFile WRITE setBackupFile)
-    Q_PROPERTY(int pageCount READ pageCount)
+    Q_PROPERTY(bool backupFile READ backupFile WRITE setBackupFile NOTIFY backupFileChanged)
+    Q_PROPERTY(int pageCount READ pageCount) // clazy:exclude=qproperty-without-notify
 
 public:
 
@@ -98,13 +102,16 @@ public:
     explicit KoDocument(KoPart *parent,
                         KUndo2Stack *undoStack = new KUndo2Stack());
 
+    virtual KPlato::Project *project() const { return nullptr; }
+    virtual QString projectName() const { return QString(); }
+
     /**
      *  Destructor.
      *
      * The destructor does not delete any attached KoView objects and it does not
      * delete the attached widget as returned by widget().
      */
-    virtual ~KoDocument();
+    ~KoDocument() override;
 
     /// XXX: Temporary!
     KoPart *documentPart() const;
@@ -163,7 +170,7 @@ public:
      *
      * @return the oasis mimetype or, if it hasn't one, the nativeformatmimetype.
      */
-    virtual QByteArray nativeOasisMimeType() const = 0;
+    QByteArray nativeOasisMimeType() const override = 0;
 
     /// Checks whether a given mimetype can be handled natively.
     bool isNativeFormat(const QByteArray& mimetype) const;
@@ -176,12 +183,12 @@ public:
      * Return the set of SupportedSpecialFormats that the application wants to
      * offer in the "Save" file dialog.
      */
-    virtual int supportedSpecialFormats() const;
+    int supportedSpecialFormats() const override;
 
     /**
      * Returns the actual mimetype of the document
      */
-    QByteArray mimeType() const;
+    QByteArray mimeType() const override;
 
     /**
      * @brief Sets the mime type for the document.
@@ -189,7 +196,7 @@ public:
      * When choosing "save as" this is also the mime type
      * selected by default.
      */
-    void setMimeType(const QByteArray & mimeType);
+    void setMimeType(const QByteArray & mimeType) override;
 
     /**
      * @brief Set the format in which the document should be saved.
@@ -200,9 +207,9 @@ public:
      * @param mimeType the mime type (format) to use.
      * @param specialOutputFlag is for "save as older version" etc.
      */
-    void setOutputMimeType(const QByteArray & mimeType, int specialOutputFlag = 0);
-    QByteArray outputMimeType() const;
-    int specialOutputFlag() const;
+    void setOutputMimeType(const QByteArray & mimeType, int specialOutputFlag = 0) override;
+    QByteArray outputMimeType() const override;
+    int specialOutputFlag() const override;
 
     /**
      * Returns true if this document was the result of opening a foreign
@@ -272,7 +279,7 @@ public:
 
     /**
      *  Tells the document that its title has been modified, either because
-     *  the modified status changes (this is done by setModified() ) or
+     *  the modified status changes (this is done by setModified()) or
      *  because the URL or the document-info's title changed.
      */
     void setTitleModified();
@@ -280,7 +287,7 @@ public:
     /**
      *  @return true if the document is empty.
      */
-    virtual bool isEmpty() const;
+    bool isEmpty() const override;
 
     /**
      *  @brief Sets the document to empty.
@@ -313,7 +320,7 @@ public:
      *
      *  You should not have to reimplement this.
      */
-    virtual bool saveToStore(KoStore *store, const QString& path);
+    bool saveToStore(KoStore *store, const QString& path) override;
 
     /**
      *  Reimplement this method to load the contents of your Calligra document,
@@ -388,7 +395,7 @@ public:
     /**
      * Checks whether the document is currently in the process of autosaving
      */
-    bool isAutosaving() const;
+    bool isAutosaving() const override;
 
     /**
      * Set whether the next openUrl call should check for an auto-saved file
@@ -455,7 +462,7 @@ public:
      * Return true if url() is a real filename, false if url() is
      * an internal url in the store, like "tar:/..."
      */
-    virtual bool isStoredExtern() const;
+    bool isStoredExtern() const override;
 
     /**
      * @return the page layout associated with this document (margins, pageSize, etc).
@@ -478,7 +485,7 @@ public:
     /**
      * Returns true if this document or any of its internal child documents are modified.
      */
-    Q_INVOKABLE bool isModified() const;
+    Q_INVOKABLE bool isModified() const override;
 
     /**
      * Returns true during loading (openUrl can be asynchronous)
@@ -513,7 +520,7 @@ public:
      * After using loadNativeFormat on a template, one wants
      * to set the url to QUrl()
      */
-    void resetURL();
+    void resetURL() override;
 
     /**
      * Set when you want an external embedded document to be stored internally
@@ -666,6 +673,8 @@ Q_SIGNALS:
 
     void titleModified(const QString &caption, bool isModified);
 
+    void backupFileChanged(bool);
+
 protected:
 
     friend class KoPart;
@@ -719,7 +728,7 @@ protected:
      *  url (using url().url()) before the filename, so that everything is kept relative
      *  to this document. For instance it will produce urls such as
      *  tar:/1/pictures/picture0.png, if the doc url is tar:/1
-     *  But do this ONLY if the document is not stored extern (see isStoredExtern() ).
+     *  But do this ONLY if the document is not stored extern (see isStoredExtern()).
      *  If it is, then the pictures should be saved to tar:/pictures.
      */
     virtual bool completeSaving(KoStore *store);
@@ -746,19 +755,19 @@ protected:
 
 public:
 
-    QString localFilePath() const;
-    void setLocalFilePath( const QString &localFilePath );
+    QString localFilePath() const override;
+    void setLocalFilePath(const QString &localFilePath);
 
     virtual KoDocumentInfoDlg* createDocumentInfoDialog(QWidget *parent, KoDocumentInfo *docInfo) const;
 
     bool isReadWrite() const;
 
-    QUrl url() const;
-    void setUrl(const QUrl &url);
+    QUrl url() const override;
+    void setUrl(const QUrl &url) override;
 
     virtual bool closeUrl(bool promptToSave = true);
 
-    virtual bool saveAs( const QUrl &url );
+    virtual bool saveAs(const QUrl &url);
 
 public Q_SLOTS:
 
@@ -801,10 +810,10 @@ private:
     class Private;
     Private *const d;
 
-    Q_PRIVATE_SLOT(d, void _k_slotJobFinished( KJob * job ))
+    Q_PRIVATE_SLOT(d, void _k_slotJobFinished(KJob * job))
     Q_PRIVATE_SLOT(d, void _k_slotStatJobFinished(KJob*))
     Q_PRIVATE_SLOT(d, void _k_slotGotMimeType(KIO::Job *job, const QString &mime))
-    Q_PRIVATE_SLOT(d, void _k_slotUploadFinished( KJob * job ))
+    Q_PRIVATE_SLOT(d, void _k_slotUploadFinished(KJob * job))
 };
 
 Q_DECLARE_METATYPE(KoDocument*)
